@@ -71,8 +71,8 @@ class Classify:
                          no more than 32.
 
             search_db: The database used for the sequence similarity search.
-                       Either `silvamod138` or `silvamod128`. No other values
-                       are currently supported. By default `silvamod138`.
+                       Either `silvamod138`, `silvamod128` or 'bold'. No other
+                       values are currently supported. By default `silvamod138`.
                        Optionally the user can provide his own custom database
                        by specifying the full path to a directory containing
                        all required files under `search_db`. See README.
@@ -105,7 +105,7 @@ class Classify:
                         By default `2.0`.
 
             min_smlrty: Determines if the minimum similarity filter is turned
-                        on or off. Pass the value `False` to turn it off.
+                        on or off. Pass any value like `False` to turn it off.
                         The minimum similarity filter prevents classification
                         to higher ranks when a minimum rank-identity is not met.
                         By default `True`.
@@ -160,7 +160,6 @@ class Classify:
         # The search hits is a file somewhere if passed #
         if self.search_hits is not None:
             self.search_hits = FilePath(self.search_hits)
-            self.search_hits.must_exist()
         # Default for the search hits file if not passed #
         if self.search_hits is None:
             self.search_hits = FilePath(self.output_dir + 'search.hits')
@@ -171,6 +170,14 @@ class Classify:
                 self.min_score = 155
             if self.search_algo == 'vsearch':
                 self.min_score = 0.75
+        # The score drop has to be a float not a string #
+        try:
+            self.score_drop = float(self.score_drop)
+        except ValueError:
+            msg = "The score drop value must be numerical (not '%s')."
+            raise ValueError(msg % self.score_drop)
+        # Turn off the minimum similarity filter if the user passed any value #
+        if self.min_smlrty is not True: self.min_smlrty = False
         # The OTU table is a file somewhere if passed #
         if self.otu_table is not None:
             self.otu_table = FilePath(self.otu_table)
@@ -194,14 +201,14 @@ class Classify:
             msg = "The search algorithm '%s' is not supported."
             raise ValueError(msg % self.search_algo)
         # Check the search database #
-        if self.search_db not in ('silvamod128', 'silvamod138'):
+        if self.search_db not in ('silvamod128', 'silvamod138', 'bold'):
             msg = "The search database '%s' is not supported."
             raise ValueError(msg % self.search_db)
-        # Check the minimum score value above zero #
+        # Check the minimum score value is above zero #
         if self.min_score < 0.0:
             msg = "The minimum score cannot be smaller than zero ('%s')."
             raise ValueError(msg % self.min_score)
-        # Check the minimum score value below zero #
+        # Check the minimum score value is below one #
         if self.min_score > 1.0:
             if self.search_algo == 'vsearch':
                 msg = "The minimum score cannot be more than 1.0 when" \
@@ -250,7 +257,7 @@ class Classify:
         if self.search_algo == 'vsearch':
             params = {'--id':      self.min_score,
                       '--mincols': 25}
-        # Build the object
+        # Build and return the object #
         return SeqSearch(input_fasta = self.fasta,
                          database    = self.database,
                          seq_type    = 'nucl',
@@ -282,10 +289,12 @@ class Classify:
         inputted. Use these objects to access the taxonomic assignments.
         """
         # Check if the search has been done already #
-        if not self.seqsearch: self.search()
+        if not self.search_hits: self.search()
         # Iterate on the sequence search results #
         result = [Query(self, query) for query in self.seqsearch.results]
-        # VSEARCH entirely forgets about sequences that had no hits #
+        # VSEARCH entirely forgets about sequences that had no hits.
+        # Instead of still listing them in the output like BLAST.
+        # So we have to add them back to the list in this awkward manner
         if self.search_algo == 'vsearch':
             reported_names = set(query.name for query in result)
             for seq in self.fasta:
