@@ -21,11 +21,11 @@ this_file = Path((inspect.stack()[0])[1])
 this_dir  = this_file.directory
 
 ###############################################################################
-def test_no_hits_sequence():
+def test_no_hits_blast():
     # The input fasta #
     fasta = this_dir.find('*.fasta')
     # The output directory #
-    output_dir = this_dir + 'results/'
+    output_dir = this_dir + 'results_blast/'
     output_dir.remove()
     # Create object #
     c = Classify(fasta       = fasta,
@@ -40,6 +40,27 @@ def test_no_hits_sequence():
     # Return #
     return c
 
+###############################################################################
+def test_no_hits_vsearch():
+    # The input fasta #
+    fasta = this_dir.find('*.fasta')
+    # The output directory #
+    output_dir = this_dir + 'results_vsearch/'
+    output_dir.remove()
+    # Create object #
+    c = Classify(fasta       = fasta,
+                 output_dir  = output_dir,
+                 search_algo = 'vsearch',
+                 num_threads = True)
+    # Run it #
+    c()
+    # Check there was no hits for the second sequence #
+    query = c.queries_by_id['homopolymer']
+    assert query.tax_string == "homopolymer\tNo hits\n"
+    # Return #
+    return c
+
 ###############################################################################
 if __name__ == '__main__':
-    classify = test_no_hits_sequence()
\ No newline at end of file
+    classify = test_no_hits_blast()
+    classify = test_no_hits_vsearch()
\ No newline at end of file
