@@ -25,7 +25,7 @@ def test_precomputed_hits():
     # The input fasta #
     fasta = this_dir.find('*.fasta')
     # The input BLAST hits #
-    hits = this_dir.find('*.hits')
+    hits = this_dir.find('precomputed.hits')
     # The output directory #
     output_dir = this_dir + 'results/'
     output_dir.remove()
@@ -39,8 +39,8 @@ def test_precomputed_hits():
     # Run it #
     c()
     # Check that the results are good #
-    assert c.queries[0].taxonomy[0] == "Micrococcaceae"
-    assert c.queries[1].taxonomy[0] == "Nocardioidaceae"
+    assert c.queries_by_id['Kocuria'].taxonomy[0] == "Kocuria"
+    assert c.queries_by_id['Marmoricola'].taxonomy[0] == "Marmoricola"
     # Return #
     return c
 
